@@ -178,7 +178,12 @@ class CloudStackPack(BaseModel):
     offering = models.ForeignKey('CloudStackOffering', related_name="cs_offering_packs")
     is_ha  = models.BooleanField(verbose_name=_("Is pack HA"), default=False)
     engine_type = models.ForeignKey('physical.EngineType', verbose_name=_("Engine Type"), related_name='cs_packs')
+    name = models.CharField(verbose_name=_("Name"),
+                 max_length=100,
+                 help_text="Cloud Stack Pack Name")
 
+    def __unicode__(self):
+        return "%s" % (self.name)
 
     def get_region(self):
         return self.offering.region
